# TODO
- [ ] Automatizzare Nevergrad
- [ ] helper che mi dice tutte le funzioni per ogni cartella con breve descrizione
- [x] passare ai modelli l'array delle colonne e non X (che sarebbe df[array colonne])
- [ ] Rendere piu semplice la funzione budget allocator
- [x] Aggiungere alla funzione mainnested la possibilità di un modello logLog
- [ ] Costruire funzione per fare il grafico della saturation
- [x] Sostituire i valori dell'adstock nel decomp_df con i valori della saturazione applicata direttamente alla spesa
- [x] Rinominare show_saturation_curves in show_trendline_curves
- [x] Aggiungere parametro Size per settare train/test dimnensioni
- [ ] Fixare Budget Allocator -> Passare i valori di Spesa normali, saturarli nella funzione (ddel Budget Allocator) e bella
